pm4py.algo.discovery.log\_skeleton package
==========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.log_skeleton.variants

Submodules
----------

pm4py.algo.discovery.log\_skeleton.algorithm module
---------------------------------------------------

.. automodule:: pm4py.algo.discovery.log_skeleton.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.log\_skeleton.outputs module
-------------------------------------------------

.. automodule:: pm4py.algo.discovery.log_skeleton.outputs
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.log\_skeleton.parameters module
----------------------------------------------------

.. automodule:: pm4py.algo.discovery.log_skeleton.parameters
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.log\_skeleton.trace\_skel module
-----------------------------------------------------

.. automodule:: pm4py.algo.discovery.log_skeleton.trace_skel
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.log_skeleton
   :members:
   :undoc-members:
   :show-inheritance:
